@@ -31,7 +31,7 @@ impl Application for DemoWindow {
 
     fn ui(&self,frame: Frame) {
         frame.show();
-        match MessageBox::new("Do you want to maximize the window?".to_string(), "Do you want to maximize the window?".to_string(), DIALOGSTYLE_QUESTION, BUTTONSTYLE_YESNO).show(frame.clone()) {
+        match MessageBox::new("Do you want to maximize the window?".to_string(), "Do you want to maximize the window?".to_string(), DIALOGSTYLE_QUESTION, BUTTONSTYLE_YESNO).show(Frame::default()) {
             RESULTS_YES => {
                 frame.show_maximized();
                 frame.set_title("The window has been maximized.".to_string());
@@ -44,6 +44,7 @@ impl Application for DemoWindow {
 
             _ => {}
         }
+        frame.set_size(500,720);
     }
 
     fn exit(&self) {
