@@ -68,6 +68,25 @@ impl Frame {
             SetWindowPos(self.handle, 0, x, y, x, y, 0);
         }
     }
+
+    /// Set window size
+    /// **Warning: This method is unstable.**
+    pub fn set_size(&self,width: i32,height: i32) {
+        use windows_sys::Win32::Foundation::RECT;
+        use windows_sys::Win32::UI::WindowsAndMessaging::*;
+        unsafe {
+            let mut rect = &mut RECT {
+                left: 0,
+                top: 0,
+                right: 0,
+                bottom: 0
+            };
+            GetWindowRect(self.handle,rect);
+
+            ShowWindow(self.handle,SW_SHOWDEFAULT);
+            SetWindowPos(self.handle, 0, rect.left, rect.top, width, height, 0);
+        }
+    }
 }
 
 #[cfg(windows)]
@@ -149,7 +168,6 @@ pub trait Application {
 
     /// Processing at application startup (optional)
     fn startup(&self,storage: Storage) {
-
     }
 
     /// Writing UI processes and events
@@ -216,6 +234,12 @@ impl Frame {
         use gtk::prelude::*;
         self.handle.set_window_position(gtk::WindowPosition::Center);
     }
+
+    /// Set window size
+    pub fn set_size(&self,width: i32,height: i32) {
+        use gtk::prelude::*;
+        self.handle.set_default_size(width,height);
+    }
 }
 
 #[cfg(unix)]
